@@ -13,7 +13,7 @@ from security_engine.models.data_source import AddressSet, DomainSet, SignTextPa
 from security_engine.handlers import HandlerType, BaseHandler
 
 
-REPO_TMP_DIR = '/tmp'
+REPO_TMP_DIR = 'tmp'
 RULE_SET_DIR = 'ruleset'
 
 
